@@ -1,3 +1,4 @@
+import sys
 from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 from time import time
@@ -71,18 +72,17 @@ class Weather:
     def get_weather_response(self):
         """
         Initializes self.response_list with the OpenWeather API\'s response.
-
-        :raises ValueError: if the location provided is invalid or the API key is not set.
         """
         config = get_user_config()
         api_key = config['API']['api_key']
 
         if 'coord' not in self.location:
-            raise ValueError('Please, set a location using wea.py -l {location} or provide one as an argument: '
-                             'wea {location}')
+            print('Please, set a location using wea.py -l {location} or provide one as an argument: wea {location}')
+            sys.exit()
         elif not api_key:
-            raise ValueError('Please, provide your OpenWeather API key. You can get one for free with an OpenWeather '
-                             'account: https://home.openweathermap.org/api_keys')
+            print('Please, provide your OpenWeather API key. You can get one for free with an OpenWeather account: '
+                  'https://home.openweathermap.org/api_keys')
+            sys.exit()
         else:
             timemachine_url1, timemachine_url2, forecast_url = get_urls(self.location)
             urls = [timemachine_url2, forecast_url]
@@ -99,7 +99,8 @@ class Weather:
         """ Initializes self.current and self.forecast if API\'s response exists. """
 
         if not self.response_list:
-            raise ValueError('Could not find API\'s response. Did you use Weather.get_weather_response()?')
+            print('Could not find API\'s response. Did you use Weather.get_weather_response()?')
+            sys.exit()
 
         timemachine_list = self.response_list[0]['hourly'] + (
             self.response_list[1]['hourly'] if len(self.response_list) > 3 else [])
@@ -120,7 +121,8 @@ class Weather:
 
         init()
         if not self.current and not self.forecast:
-            raise ValueError('Could not find any weather report to print. Did you use Weather.handle_response()?')
+            print('Could not find any weather report to print. Did you use Weather.handle_response()?')
+            sys.exit()
 
         print(location_prologue[self.lang], self.location['name'].title())
         if self.current:
